@@ -17,6 +17,7 @@
  */
 
 #include "config.h"
+#include "version.h"
 
 #include "application.h"
 #include "panel-layout.h"
@@ -27,6 +28,7 @@
 #include <locale.h>
 #include <stdbool.h>
 
+#define PROFILE_TR N_("Use specified profile")
 #define COMMAND_DES_TR N_("Run command on already opened panel")
 #define REMOTE_DES_TR N_("Run remote command on panel applet")
 #define DEFAULT_PROFILE "default"
@@ -71,12 +73,13 @@ static void activate_shutdown(GSimpleAction *simple, GVariant *param, gpointer d
 static void activate_exit(GSimpleAction *simple, GVariant *param, gpointer data);
 static void activate_restart(GSimpleAction *simple, GVariant *param, gpointer data);
 
-static const GOptionEntry entries[] =
-    { { "version", 'v', 0, G_OPTION_ARG_NONE, NULL, N_("Print version and exit"), NULL },
-      { "profile", 'p', 0, G_OPTION_ARG_STRING, NULL, N_("Use specified profile"), N_("profile") },
-      { "command", 'c', 0, G_OPTION_ARG_STRING, NULL, COMMAND_DES_TR, N_("cmd") },
-      { "remote-command", 'r', 0, G_OPTION_ARG_STRING_ARRAY, NULL, REMOTE_DES_TR, N_("cmd") },
-      { NULL } };
+static const GOptionEntry entries[] = {
+	{ "version", 'v', 0, G_OPTION_ARG_NONE, NULL, N_("Print version and exit"), NULL },
+	{ "profile", 'p', 0, G_OPTION_ARG_STRING, NULL, PROFILE_TR, N_("profile") },
+	{ "command", 'c', 0, G_OPTION_ARG_STRING, NULL, COMMAND_DES_TR, N_("cmd") },
+	{ "remote-command", 'r', 0, G_OPTION_ARG_STRING_ARRAY, NULL, REMOTE_DES_TR, N_("cmd") },
+	{ NULL }
+};
 
 static const GActionEntry vala_panel_application_app_entries[10] = {
 	{ "preferences", activate_preferences, NULL, NULL, NULL, { 0 } },
@@ -90,27 +93,30 @@ static const GActionEntry vala_panel_application_app_entries[10] = {
 	{ "quit", activate_exit, NULL, NULL, NULL, { 0 } },
 	{ "restart", activate_restart, NULL, NULL, NULL, { 0 } },
 };
-static const GActionEntry vala_panel_application_menu_entries[3] =
-    { { "launch-id", activate_menu_launch_id, "s", NULL, NULL, { 0 } },
-      { "launch-uri", activate_menu_launch_uri, "s", NULL, NULL, { 0 } },
-      { "launch-command", activate_menu_launch_command, "s", NULL, NULL, { 0 } } };
+static const GActionEntry vala_panel_application_menu_entries[3] = {
+	{ "launch-id", activate_menu_launch_id, "s", NULL, NULL, { 0 } },
+	{ "launch-uri", activate_menu_launch_uri, "s", NULL, NULL, { 0 } },
+	{ "launch-command", activate_menu_launch_command, "s", NULL, NULL, { 0 } }
+};
 
 enum
 {
-	VALA_PANEL_APP_DUMMY_PROPERTY,
-	VALA_PANEL_APP_PROFILE,
-	VALA_PANEL_APP_RUN_COMMAND,
-	VALA_PANEL_APP_TERMINAL_COMMAND,
-	VALA_PANEL_APP_LOCK_COMMAND,
-	VALA_PANEL_APP_LOGOUT_COMMAND,
-	VALA_PANEL_APP_SHUTDOWN_COMMAND,
-	VALA_PANEL_APP_IS_DARK,
-	VALA_PANEL_APP_IS_CUSTOM,
-	VALA_PANEL_APP_CSS,
-	VALA_PANEL_APP_ALL
+	APP_DUMMY_PROPERTY,
+	APP_PROFILE,
+	APP_RUN_COMMAND,
+	APP_TERMINAL_COMMAND,
+	APP_LOCK_COMMAND,
+	APP_LOGOUT_COMMAND,
+	APP_SHUTDOWN_COMMAND,
+	APP_IS_DARK,
+	APP_IS_CUSTOM,
+	APP_CSS,
+	APP_ALL
 };
 
-static inline void destroy0(GtkWidget *x, void *data)
+static GParamSpec *app_specs[APP_ALL];
+
+static inline void destroy0(GtkWidget *x, G_GNUC_UNUSED void *data)
 {
 	gtk_widget_destroy0(x);
 }
@@ -138,12 +144,11 @@ static void apply_styling(ValaPanelApplication *app)
 	{
 		gtk_style_context_remove_provider_for_screen(gdk_screen_get_default(),
 		                                             GTK_STYLE_PROVIDER(app->provider));
-		g_object_unref(app->provider);
-		app->provider = NULL;
+		g_clear_object(&app->provider);
 	}
 }
 
-ValaPanelApplication *vala_panel_application_new()
+ValaPanelApplication *vala_panel_application_new(void)
 {
 	return (ValaPanelApplication *)g_object_new(vala_panel_application_get_type(),
 	                                            "application-id",
@@ -193,21 +198,18 @@ static void vala_panel_application_shutdown(GApplication *base)
 	{
 		GtkWindow *w = GTK_WINDOW(il->data);
 		gtk_window_set_application(w, NULL);
-		gtk_widget_destroy(GTK_WIDGET(w));
 	}
 	G_APPLICATION_CLASS(vala_panel_application_parent_class)->shutdown(base);
 	if (VALA_PANEL_APPLICATION(base)->restart)
 	{
 		g_autoptr(GError) err = NULL;
-		char cwd[1024];
-		char *tmp;
-		tmp                = getcwd(cwd, 1024);
-		const char *argv[] = { GETTEXT_PACKAGE,
-			               "-p",
-			               VALA_PANEL_APPLICATION(base)->profile,
-			               NULL };
+		char cwd[PATH_MAX];
+		char *cwdp         = getcwd(cwd, PATH_MAX);
+		const char *argv[] = {
+			GETTEXT_PACKAGE, "-p", VALA_PANEL_APPLICATION(base)->profile, NULL
+		};
 		g_auto(GStrv) envp = g_get_environ();
-		g_spawn_async(cwd,
+		g_spawn_async(cwdp,
 		              (GStrv)argv,
 		              envp,
 		              G_SPAWN_SEARCH_PATH,
@@ -220,7 +222,8 @@ static void vala_panel_application_shutdown(GApplication *base)
 	}
 }
 
-static gint vala_panel_app_handle_local_options(GApplication *application, GVariantDict *options)
+static gint vala_panel_app_handle_local_options(G_GNUC_UNUSED GApplication *application,
+                                                GVariantDict *options)
 {
 	if (g_variant_dict_contains(options, "version"))
 	{
@@ -294,10 +297,9 @@ static int vala_panel_app_command_line(GApplication *application,
 						                                     il->data),
 						                                 command_name);
 				}
-				//            g_list_free(applets);
+				g_list_free(applets);
 			}
 		}
-		//    g_list_free(windows);
 	}
 	g_application_activate(application);
 	return 0;
@@ -347,7 +349,7 @@ static bool load_settings(ValaPanelApplication *app)
 	return true;
 }
 
-static void _ensure_user_config_dirs()
+static void _ensure_user_config_dirs(void)
 {
 	g_autofree char *dir = _user_config_file_name_new("");
 	/* make sure the private profile and panels dir exists */
@@ -397,11 +399,11 @@ static void vala_panel_app_finalize(GObject *object)
 	g_free0(app->logout_command);
 	g_free0(app->shutdown_command);
 	g_clear_object(&app->provider);
-	g_free(app->profile);
-	(*G_OBJECT_CLASS(vala_panel_application_parent_class)->finalize)(object);
+	g_free0(app->profile);
+	G_OBJECT_CLASS(vala_panel_application_parent_class)->finalize(object);
 }
 
-static void vala_panel_app_set_property(GObject *object, guint prop_id, const GValue *value,
+static void vala_panel_app_set_property(GObject *object, uint id, const GValue *value,
                                         GParamSpec *pspec)
 {
 	ValaPanelApplication *app;
@@ -409,99 +411,98 @@ static void vala_panel_app_set_property(GObject *object, guint prop_id, const GV
 
 	app = VALA_PANEL_APPLICATION(object);
 
-	switch (prop_id)
+	switch (id)
 	{
-	case VALA_PANEL_APP_IS_DARK:
+	case APP_IS_DARK:
 		app->dark = g_value_get_boolean(value);
 		apply_styling(app);
 		g_object_notify_by_pspec(object, pspec);
 		break;
-	case VALA_PANEL_APP_IS_CUSTOM:
+	case APP_IS_CUSTOM:
 		app->custom = g_value_get_boolean(value);
 		apply_styling(app);
 		g_object_notify_by_pspec(object, pspec);
 		break;
-	case VALA_PANEL_APP_TERMINAL_COMMAND:
+	case APP_TERMINAL_COMMAND:
 		g_free0(app->terminal_command);
 		app->terminal_command = g_strdup(g_value_get_string(value));
 		g_object_notify_by_pspec(object, pspec);
 		break;
-	case VALA_PANEL_APP_RUN_COMMAND:
+	case APP_RUN_COMMAND:
 		g_free0(app->run_command);
 		app->run_command = g_strdup(g_value_get_string(value));
 		g_object_notify_by_pspec(object, pspec);
 		break;
-	case VALA_PANEL_APP_LOCK_COMMAND:
+	case APP_LOCK_COMMAND:
 		g_free0(app->lock_command);
 		app->lock_command = g_strdup(g_value_get_string(value));
 		g_object_notify_by_pspec(object, pspec);
 		break;
-	case VALA_PANEL_APP_LOGOUT_COMMAND:
+	case APP_LOGOUT_COMMAND:
 		g_free0(app->logout_command);
 		app->logout_command = g_strdup(g_value_get_string(value));
 		g_object_notify_by_pspec(object, pspec);
 		break;
-	case VALA_PANEL_APP_SHUTDOWN_COMMAND:
+	case APP_SHUTDOWN_COMMAND:
 		g_free0(app->shutdown_command);
 		app->shutdown_command = g_strdup(g_value_get_string(value));
 		g_object_notify_by_pspec(object, pspec);
 		break;
-	case VALA_PANEL_APP_PROFILE:
+	case APP_PROFILE:
 		g_free0(app->profile);
 		app->profile = g_strdup(g_value_get_string(value));
 		g_object_notify_by_pspec(object, pspec);
 		break;
-	case VALA_PANEL_APP_CSS:
+	case APP_CSS:
 		g_free0(app->css);
 		app->css = g_strdup(g_value_get_string(value));
 		apply_styling(app);
 		g_object_notify_by_pspec(object, pspec);
 		break;
 	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
+		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, id, pspec);
 		break;
 	}
 }
 
-static void vala_panel_app_get_property(GObject *object, guint prop_id, GValue *value,
-                                        GParamSpec *pspec)
+static void vala_panel_app_get_property(GObject *object, uint id, GValue *value, GParamSpec *pspec)
 {
 	ValaPanelApplication *app;
 	g_return_if_fail(VALA_PANEL_IS_APPLICATION(object));
 
 	app = VALA_PANEL_APPLICATION(object);
 
-	switch (prop_id)
+	switch (id)
 	{
-	case VALA_PANEL_APP_IS_DARK:
+	case APP_IS_DARK:
 		g_value_set_boolean(value, app->dark);
 		break;
-	case VALA_PANEL_APP_IS_CUSTOM:
+	case APP_IS_CUSTOM:
 		g_value_set_boolean(value, app->custom);
 		break;
-	case VALA_PANEL_APP_RUN_COMMAND:
+	case APP_RUN_COMMAND:
 		g_value_set_string(value, app->run_command);
 		break;
-	case VALA_PANEL_APP_TERMINAL_COMMAND:
+	case APP_TERMINAL_COMMAND:
 		g_value_set_string(value, app->terminal_command);
 		break;
-	case VALA_PANEL_APP_LOCK_COMMAND:
+	case APP_LOCK_COMMAND:
 		g_value_set_string(value, app->lock_command);
 		break;
-	case VALA_PANEL_APP_LOGOUT_COMMAND:
+	case APP_LOGOUT_COMMAND:
 		g_value_set_string(value, app->logout_command);
 		break;
-	case VALA_PANEL_APP_SHUTDOWN_COMMAND:
+	case APP_SHUTDOWN_COMMAND:
 		g_value_set_string(value, app->shutdown_command);
 		break;
-	case VALA_PANEL_APP_PROFILE:
+	case APP_PROFILE:
 		g_value_set_string(value, app->profile);
 		break;
-	case VALA_PANEL_APP_CSS:
+	case APP_CSS:
 		g_value_set_string(value, app->css);
 		break;
 	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
+		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, id, pspec);
 		break;
 	}
 }
@@ -514,7 +515,8 @@ static inline void file_chooser_helper(GtkFileChooser *self, ValaPanelApplicatio
 
 /* TODO: Move activate_menu to hidden toplevel interface, it is not X11-specific */
 
-static void activate_menu(GSimpleAction *simple, GVariant *param, gpointer data)
+static void activate_menu(G_GNUC_UNUSED GSimpleAction *simple, G_GNUC_UNUSED GVariant *param,
+                          gpointer data)
 {
 	GtkApplication *app = GTK_APPLICATION(data);
 	GList *windows      = gtk_application_get_windows(app);
@@ -532,13 +534,13 @@ static void activate_menu(GSimpleAction *simple, GVariant *param, gpointer data)
 				if (success)
 					break;
 			}
-			//            g_list_free(applets);
+			g_list_free(applets);
 		}
 	}
-	//    g_list_free(windows);
 }
 
-static void activate_panel_preferences(GSimpleAction *simple, GVariant *param, gpointer data)
+static void activate_panel_preferences(G_GNUC_UNUSED GSimpleAction *simple,
+                                       G_GNUC_UNUSED GVariant *param, gpointer data)
 {
 	GtkApplication *app   = GTK_APPLICATION(data);
 	GList *windows        = gtk_application_get_windows(app);
@@ -558,7 +560,8 @@ static void activate_panel_preferences(GSimpleAction *simple, GVariant *param, g
 	}
 }
 
-static void activate_preferences(GSimpleAction *simple, GVariant *param, gpointer data)
+static void activate_preferences(G_GNUC_UNUSED GSimpleAction *simple, G_GNUC_UNUSED GVariant *param,
+                                 gpointer data)
 {
 	static GtkDialog *pref_dialog = NULL;
 	ValaPanelApplication *self    = VALA_PANEL_APPLICATION(data);
@@ -587,7 +590,8 @@ static void activate_preferences(GSimpleAction *simple, GVariant *param, gpointe
 	g_signal_connect_after(pref_dialog, "response", G_CALLBACK(destroy0), &pref_dialog);
 }
 
-static void activate_about(GSimpleAction *simple, GVariant *param, gpointer data)
+static void activate_about(G_GNUC_UNUSED GSimpleAction *simple, G_GNUC_UNUSED GVariant *param,
+                           G_GNUC_UNUSED gpointer data)
 {
 	g_autoptr(GtkBuilder) builder =
 	    gtk_builder_new_from_resource("/org/vala-panel/app/about.ui");
@@ -600,143 +604,120 @@ static void activate_about(GSimpleAction *simple, GVariant *param, gpointer data
 	g_signal_connect(d, "hide", G_CALLBACK(gtk_widget_destroy), NULL);
 }
 
-static void activate_run(GSimpleAction *simple, GVariant *param, gpointer data)
+static void activate_run(G_GNUC_UNUSED GSimpleAction *simple, G_GNUC_UNUSED GVariant *param,
+                         gpointer data)
 {
 	ValaPanelApplication *app = VALA_PANEL_APPLICATION(data);
 	g_autoptr(GVariant) par   = g_variant_new_string(app->run_command);
 	activate_menu_launch_command(NULL, par, app);
 }
 
-static void activate_lock(GSimpleAction *simple, GVariant *param, gpointer data)
+static void activate_lock(G_GNUC_UNUSED GSimpleAction *simple, G_GNUC_UNUSED GVariant *param,
+                          gpointer data)
 {
 	ValaPanelApplication *app = VALA_PANEL_APPLICATION(data);
 	g_autoptr(GVariant) par   = g_variant_new_string(app->lock_command);
 	activate_menu_launch_command(NULL, par, app);
 }
 
-static void activate_logout(GSimpleAction *simple, GVariant *param, gpointer data)
+static void activate_logout(G_GNUC_UNUSED GSimpleAction *simple, G_GNUC_UNUSED GVariant *param,
+                            gpointer data)
 {
 	ValaPanelApplication *app = VALA_PANEL_APPLICATION(data);
 	g_autoptr(GVariant) par   = g_variant_new_string(app->logout_command);
 	activate_menu_launch_command(NULL, par, app);
 }
 
-static void activate_shutdown(GSimpleAction *simple, GVariant *param, gpointer data)
+static void activate_shutdown(G_GNUC_UNUSED GSimpleAction *simple, G_GNUC_UNUSED GVariant *param,
+                              gpointer data)
 {
 	ValaPanelApplication *app = VALA_PANEL_APPLICATION(data);
 	g_autoptr(GVariant) par   = g_variant_new_string(app->shutdown_command);
 	activate_menu_launch_command(NULL, par, app);
 }
-static void activate_exit(GSimpleAction *simple, GVariant *param, gpointer data)
+static void activate_exit(G_GNUC_UNUSED GSimpleAction *simple, G_GNUC_UNUSED GVariant *param,
+                          gpointer data)
 {
-	ValaPanelApplication *app = (ValaPanelApplication *)data;
+	ValaPanelApplication *app = VALA_PANEL_APPLICATION(data);
 	app->restart              = false;
 	g_application_quit(G_APPLICATION(app));
 }
 
-static void activate_restart(GSimpleAction *simple, GVariant *param, gpointer data)
+static void activate_restart(G_GNUC_UNUSED GSimpleAction *simple, G_GNUC_UNUSED GVariant *param,
+                             gpointer data)
 {
-	ValaPanelApplication *app = (ValaPanelApplication *)data;
+	ValaPanelApplication *app = VALA_PANEL_APPLICATION(data);
 	app->restart              = true;
 	g_application_quit(G_APPLICATION(app));
 }
 
 static void vala_panel_application_class_init(ValaPanelApplicationClass *klass)
 {
-	vala_panel_application_parent_class                = g_type_class_peek_parent(klass);
-	((GApplicationClass *)klass)->startup              = vala_panel_application_startup;
-	((GApplicationClass *)klass)->shutdown             = vala_panel_application_shutdown;
-	((GApplicationClass *)klass)->activate             = vala_panel_application_activate;
-	((GApplicationClass *)klass)->handle_local_options = vala_panel_app_handle_local_options;
-	((GApplicationClass *)klass)->command_line         = vala_panel_app_command_line;
-	G_OBJECT_CLASS(klass)->get_property                = vala_panel_app_get_property;
-	G_OBJECT_CLASS(klass)->set_property                = vala_panel_app_set_property;
-	G_OBJECT_CLASS(klass)->finalize                    = vala_panel_app_finalize;
-	g_object_class_install_property(G_OBJECT_CLASS(klass),
-	                                VALA_PANEL_APP_PROFILE,
-	                                g_param_spec_string("profile",
-	                                                    "profile",
-	                                                    "profile",
-	                                                    "default",
-	                                                    G_PARAM_STATIC_STRINGS |
-	                                                        G_PARAM_READABLE |
-	                                                        G_PARAM_WRITABLE));
-	g_object_class_install_property(G_OBJECT_CLASS(klass),
-	                                VALA_PANEL_APP_RUN_COMMAND,
-	                                g_param_spec_string(VP_KEY_RUN,
-	                                                    VP_KEY_RUN,
-	                                                    VP_KEY_RUN,
-	                                                    NULL,
-	                                                    G_PARAM_STATIC_STRINGS |
-	                                                        G_PARAM_READABLE |
-	                                                        G_PARAM_WRITABLE));
-	g_object_class_install_property(G_OBJECT_CLASS(klass),
-	                                VALA_PANEL_APP_TERMINAL_COMMAND,
-	                                g_param_spec_string(VP_KEY_TERMINAL,
-	                                                    VP_KEY_TERMINAL,
-	                                                    VP_KEY_TERMINAL,
-	                                                    NULL,
-	                                                    G_PARAM_STATIC_STRINGS |
-	                                                        G_PARAM_READABLE |
-	                                                        G_PARAM_WRITABLE));
-	g_object_class_install_property(G_OBJECT_CLASS(klass),
-	                                VALA_PANEL_APP_LOCK_COMMAND,
-	                                g_param_spec_string(VP_KEY_LOCK,
-	                                                    VP_KEY_LOCK,
-	                                                    VP_KEY_LOCK,
-	                                                    NULL,
-	                                                    G_PARAM_STATIC_STRINGS |
-	                                                        G_PARAM_READABLE |
-	                                                        G_PARAM_WRITABLE));
-	g_object_class_install_property(G_OBJECT_CLASS(klass),
-	                                VALA_PANEL_APP_LOGOUT_COMMAND,
-	                                g_param_spec_string(VP_KEY_LOGOUT,
-	                                                    VP_KEY_LOGOUT,
-	                                                    VP_KEY_LOGOUT,
-	                                                    NULL,
-	                                                    G_PARAM_STATIC_STRINGS |
-	                                                        G_PARAM_READABLE |
-	                                                        G_PARAM_WRITABLE));
-	g_object_class_install_property(G_OBJECT_CLASS(klass),
-	                                VALA_PANEL_APP_SHUTDOWN_COMMAND,
-	                                g_param_spec_string(VP_KEY_SHUTDOWN,
-	                                                    VP_KEY_SHUTDOWN,
-	                                                    VP_KEY_SHUTDOWN,
-	                                                    NULL,
-	                                                    G_PARAM_STATIC_STRINGS |
-	                                                        G_PARAM_READABLE |
-	                                                        G_PARAM_WRITABLE));
-	g_object_class_install_property(G_OBJECT_CLASS(klass),
-	                                VALA_PANEL_APP_IS_DARK,
-	                                g_param_spec_boolean(VP_KEY_DARK,
-	                                                     VP_KEY_DARK,
-	                                                     VP_KEY_DARK,
-	                                                     false,
-	                                                     G_PARAM_STATIC_STRINGS |
-	                                                         G_PARAM_READABLE |
-	                                                         G_PARAM_WRITABLE));
-	g_object_class_install_property(G_OBJECT_CLASS(klass),
-	                                VALA_PANEL_APP_IS_CUSTOM,
-	                                g_param_spec_boolean(VP_KEY_CUSTOM,
-	                                                     VP_KEY_CUSTOM,
-	                                                     VP_KEY_CUSTOM,
-	                                                     false,
-	                                                     G_PARAM_STATIC_STRINGS |
-	                                                         G_PARAM_READABLE |
-	                                                         G_PARAM_WRITABLE));
-	g_object_class_install_property(G_OBJECT_CLASS(klass),
-	                                VALA_PANEL_APP_CSS,
-	                                g_param_spec_string(VP_KEY_CSS,
-	                                                    VP_KEY_CSS,
-	                                                    VP_KEY_CSS,
-	                                                    NULL,
-	                                                    G_PARAM_STATIC_STRINGS |
-	                                                        G_PARAM_READABLE |
-	                                                        G_PARAM_WRITABLE));
+	G_APPLICATION_CLASS(klass)->startup              = vala_panel_application_startup;
+	G_APPLICATION_CLASS(klass)->shutdown             = vala_panel_application_shutdown;
+	G_APPLICATION_CLASS(klass)->activate             = vala_panel_application_activate;
+	G_APPLICATION_CLASS(klass)->handle_local_options = vala_panel_app_handle_local_options;
+	G_APPLICATION_CLASS(klass)->command_line         = vala_panel_app_command_line;
+	G_OBJECT_CLASS(klass)->get_property              = vala_panel_app_get_property;
+	G_OBJECT_CLASS(klass)->set_property              = vala_panel_app_set_property;
+	G_OBJECT_CLASS(klass)->finalize                  = vala_panel_app_finalize;
+	app_specs[APP_PROFILE]                           = g_param_spec_string("profile",
+                                                     "profile",
+                                                     "profile",
+                                                     "default",
+                                                     G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+	app_specs[APP_RUN_COMMAND] =
+	    g_param_spec_string(VP_KEY_RUN,
+	                        VP_KEY_RUN,
+	                        VP_KEY_RUN,
+	                        NULL,
+	                        G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+	app_specs[APP_TERMINAL_COMMAND] =
+	    g_param_spec_string(VP_KEY_TERMINAL,
+	                        VP_KEY_TERMINAL,
+	                        VP_KEY_TERMINAL,
+	                        NULL,
+	                        G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+	app_specs[APP_LOCK_COMMAND] =
+	    g_param_spec_string(VP_KEY_LOCK,
+	                        VP_KEY_LOCK,
+	                        VP_KEY_LOCK,
+	                        NULL,
+	                        G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+	app_specs[APP_LOGOUT_COMMAND] =
+	    g_param_spec_string(VP_KEY_LOGOUT,
+	                        VP_KEY_LOGOUT,
+	                        VP_KEY_LOGOUT,
+	                        NULL,
+	                        G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+	app_specs[APP_SHUTDOWN_COMMAND] =
+	    g_param_spec_string(VP_KEY_SHUTDOWN,
+	                        VP_KEY_SHUTDOWN,
+	                        VP_KEY_SHUTDOWN,
+	                        NULL,
+	                        G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+	app_specs[APP_IS_DARK]   = g_param_spec_boolean(VP_KEY_DARK,
+                                                      VP_KEY_DARK,
+                                                      VP_KEY_DARK,
+                                                      false,
+                                                      G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+	app_specs[APP_IS_CUSTOM] = g_param_spec_boolean(VP_KEY_CUSTOM,
+	                                                VP_KEY_CUSTOM,
+	                                                VP_KEY_CUSTOM,
+	                                                false,
+	                                                G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+	app_specs[APP_CSS]       = g_param_spec_string(VP_KEY_CSS,
+                                                 VP_KEY_CSS,
+                                                 VP_KEY_CSS,
+                                                 NULL,
+                                                 G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+	g_object_class_install_properties(G_OBJECT_CLASS(klass), APP_ALL, app_specs);
 }
 
 int main(int argc, char *argv[])
 {
 	ValaPanelApplication *app = vala_panel_application_new();
-	return g_application_run(G_APPLICATION(app), argc, argv);
+	int ret                   = g_application_run(G_APPLICATION(app), argc, argv);
+	g_clear_object(&app);
+	return ret;
 }
