@@ -17,23 +17,26 @@
  */
 #include "applet-info.h"
 #include "config.h"
+#include "version.h"
 
 #include <glib/gi18n.h>
 
-#define APPLET_INFO_GROUP "Plugin"
+#define INFO_GROUP "Plugin"
 
-#define APPLET_INFO_NAME "Name"
-#define APPLET_INFO_DESCRIPTION "Description"
-#define APPLET_INFO_ICON "Icon"
-#define APPLET_INFO_AUTHORS "Authors"
-#define APPLET_INFO_WEBSITE "Website"
-#define APPLET_INFO_HELP_URI "HelpURI"
-#define APPLET_INFO_LICENSE "License"
-#define APPLET_INFO_VERSION "Version"
-#define APPLET_INFO_EXCLUSIVE "Exclusive"
+#define INFO_NAME "Name"
+#define INFO_DESCRIPTION "Description"
+#define INFO_COMMENT "Comment"
+#define INFO_ICON "Icon"
+#define INFO_AUTHORS "Authors"
+#define INFO_WEBSITE "Website"
+#define INFO_HELP_URI "HelpURI"
+#define INFO_LICENSE "License"
+#define INFO_VERSION "Version"
+#define INFO_EXCLUSIVE "Exclusive"
 
 struct _ValaPanelAppletInfo
 {
+	GType type;
 	char *module_name;
 	char *name;
 	char *description;
@@ -46,16 +49,19 @@ struct _ValaPanelAppletInfo
 	GtkLicense license;
 };
 
-static GtkLicense vala_panel_applet_info_get_license_from_name(const char *license_name)
+#define fb(str, fbs) (str) != NULL ? (str) : (fbs)
+
+static GtkLicense vp_applet_info_get_lic_from_name(const char *license_name)
 {
 	GEnumClass *enum_class = (GEnumClass *)g_type_class_ref(gtk_license_get_type());
 	GEnumValue *val        = g_enum_get_value_by_name(enum_class, license_name);
 	if (!val)
 		val = g_enum_get_value_by_nick(enum_class, license_name);
+	g_type_class_unref(enum_class);
 	return val ? (GtkLicense)val->value : GTK_LICENSE_LGPL_3_0;
 }
 
-ValaPanelAppletInfo *vala_panel_applet_info_load(const char *extension_name)
+ValaPanelAppletInfo *vala_panel_applet_info_load(const char *extension_name, GType plugin_type)
 {
 	g_autoptr(GKeyFile) file      = g_key_file_new();
 	g_autofree char *desktop_name = g_strdup_printf(PLUGINS_DATA "/%s.plugin", extension_name);
@@ -64,50 +70,42 @@ ValaPanelAppletInfo *vala_panel_applet_info_load(const char *extension_name)
 	    g_key_file_load_from_file(file, desktop_name, G_KEY_FILE_KEEP_TRANSLATIONS, &err);
 	if (err)
 		g_critical("%s: %s\n", desktop_name, err->message);
-	if (!loaded || err)
+	if (!loaded || err || !G_TYPE_IS_CLASSED(plugin_type))
 		return NULL;
 	struct _ValaPanelAppletInfo *ret =
 	    (struct _ValaPanelAppletInfo *)g_slice_alloc0(sizeof(struct _ValaPanelAppletInfo));
-	char *tmp =
-	    g_key_file_get_locale_string(file, APPLET_INFO_GROUP, APPLET_INFO_NAME, NULL, NULL);
+	ret->type        = plugin_type;
+	char *tmp        = g_key_file_get_locale_string(file, INFO_GROUP, INFO_NAME, NULL, NULL);
 	ret->module_name = g_strdup(extension_name);
-	ret->name        = tmp != NULL ? tmp : g_strdup(_("Applet"));
-	tmp              = g_key_file_get_locale_string(file,
-                                           APPLET_INFO_GROUP,
-                                           APPLET_INFO_DESCRIPTION,
-                                           NULL,
-                                           NULL);
-	ret->description = tmp != NULL ? tmp : g_strdup(_("Vala Panel Applet"));
-	tmp              = g_key_file_get_string(file, APPLET_INFO_GROUP, APPLET_INFO_ICON, NULL);
-	ret->icon_name   = tmp != NULL ? tmp : g_strdup("package-x-generic");
+	ret->name        = fb(tmp, g_strdup(_("Applet")));
+	tmp = g_key_file_get_locale_string(file, INFO_GROUP, INFO_DESCRIPTION, NULL, NULL);
+	g_autofree char *cmt =
+	    g_key_file_get_locale_string(file, INFO_GROUP, INFO_COMMENT, NULL, NULL);
+	ret->description = fb(cmt, fb(tmp, g_strdup(_("Vala Panel Applet"))));
+	tmp              = g_key_file_get_string(file, INFO_GROUP, INFO_ICON, NULL);
+	ret->icon_name   = fb(tmp, g_strdup("package-x-generic"));
 	g_key_file_set_list_separator(file, ';');
-	GStrv tmp_list =
-	    g_key_file_get_string_list(file, APPLET_INFO_GROUP, APPLET_INFO_AUTHORS, NULL, NULL);
-	ret->authors = tmp_list != NULL
-	                   ? tmp_list
-	                   : g_strsplit("Konstantin <ria.freelander@gmail.com>;", ";", 0);
-	tmp = g_key_file_get_string(file, APPLET_INFO_GROUP, APPLET_INFO_WEBSITE, NULL);
-	ret->website =
-	    tmp != NULL ? tmp : g_strdup("https://gitlab.com/vala-panel-project/vala-panel");
-	tmp =
-	    g_key_file_get_locale_string(file, APPLET_INFO_GROUP, APPLET_INFO_HELP_URI, NULL, NULL);
+	GStrv tmp_list = g_key_file_get_string_list(file, INFO_GROUP, INFO_AUTHORS, NULL, NULL);
+	ret->authors   = fb(tmp_list, g_strsplit("Konstantin <ria.freelander@gmail.com>;", ";", 0));
+	tmp            = g_key_file_get_string(file, INFO_GROUP, INFO_WEBSITE, NULL);
+	ret->website   = fb(tmp, g_strdup("https://gitlab.com/vala-panel-project/vala-panel"));
+	tmp            = g_key_file_get_locale_string(file, INFO_GROUP, INFO_HELP_URI, NULL, NULL);
 	ret->help_uri =
-	    tmp != NULL ? tmp
-	                : g_strdup("https://gitlab.com/vala-panel-project/vala-panel/wikis/home");
-	tmp = g_key_file_get_string(file, APPLET_INFO_GROUP, APPLET_INFO_WEBSITE, NULL);
-	ret->license =
-	    tmp != NULL ? vala_panel_applet_info_get_license_from_name(tmp) : GTK_LICENSE_LGPL_3_0;
-	tmp          = g_key_file_get_string(file, APPLET_INFO_GROUP, APPLET_INFO_VERSION, NULL);
-	ret->version = tmp != NULL ? tmp : g_strdup(VERSION);
-	ret->exclusive =
-	    g_key_file_get_boolean(file, APPLET_INFO_GROUP, APPLET_INFO_EXCLUSIVE, NULL);
-	return ret;
+	    fb(tmp, g_strdup("https://gitlab.com/vala-panel-project/vala-panel/wikis/home"));
+	tmp          = g_key_file_get_string(file, INFO_GROUP, INFO_LICENSE, NULL);
+	ret->license = tmp != NULL ? vp_applet_info_get_lic_from_name(tmp) : GTK_LICENSE_LGPL_3_0;
+	g_clear_pointer(&tmp, g_free);
+	tmp            = g_key_file_get_string(file, INFO_GROUP, INFO_VERSION, NULL);
+	ret->version   = fb(tmp, g_strdup(VERSION));
+	ret->exclusive = g_key_file_get_boolean(file, INFO_GROUP, INFO_EXCLUSIVE, NULL);
+	return (ValaPanelAppletInfo *)ret;
 }
 
 ValaPanelAppletInfo *vala_panel_applet_info_duplicate(void *info)
 {
 	struct _ValaPanelAppletInfo *ainfo = (struct _ValaPanelAppletInfo *)info;
 	struct _ValaPanelAppletInfo *ret   = g_slice_alloc0(sizeof(struct _ValaPanelAppletInfo));
+	ret->type                          = ainfo->type;
 	ret->module_name                   = g_strdup(ainfo->module_name);
 	ret->name                          = g_strdup(ainfo->name);
 	ret->description                   = g_strdup(ainfo->description);
@@ -126,7 +124,7 @@ ValaPanelAppletInfo *vala_panel_applet_info_duplicate(void *info)
 	ret->license   = ainfo->license;
 	ret->version   = g_strdup(ainfo->version);
 	ret->exclusive = ainfo->exclusive;
-	return ret;
+	return (ValaPanelAppletInfo *)ret;
 }
 
 void vala_panel_applet_info_free(void *info)
@@ -146,6 +144,12 @@ void vala_panel_applet_info_free(void *info)
 G_DEFINE_BOXED_TYPE(ValaPanelAppletInfo, vala_panel_applet_info,
                     (GBoxedCopyFunc)vala_panel_applet_info_duplicate, vala_panel_applet_info_free)
 
+GType vala_panel_applet_info_get_stored_type(ValaPanelAppletInfo *info)
+{
+	struct _ValaPanelAppletInfo *ainfo = ((struct _ValaPanelAppletInfo *)info);
+	return ainfo->type;
+}
+
 const char *vala_panel_applet_info_get_module_name(ValaPanelAppletInfo *info)
 {
 	struct _ValaPanelAppletInfo *ainfo = ((struct _ValaPanelAppletInfo *)info);
@@ -173,7 +177,7 @@ const char *vala_panel_applet_info_get_icon_name(ValaPanelAppletInfo *info)
 const char *const *vala_panel_applet_info_get_authors(ValaPanelAppletInfo *info)
 {
 	struct _ValaPanelAppletInfo *ainfo = ((struct _ValaPanelAppletInfo *)info);
-	return ainfo->authors;
+	return (const char *const *)ainfo->authors;
 }
 
 const char *vala_panel_applet_info_get_website(ValaPanelAppletInfo *info)
