@@ -26,10 +26,14 @@ G_BEGIN_DECLS
 
 typedef struct _ValaPanelAppeltInfo ValaPanelAppletInfo;
 
-ValaPanelAppletInfo *vala_panel_applet_info_load(const char *extension_name);
+#define VALA_PANEL_APPLET_EXCLUSIVE "ValaPanel-Exclusive"
+#define VALA_PANEL_APPLET_EXTENSION_POINT "vala-panel-applet-module"
+
+ValaPanelAppletInfo *vala_panel_applet_info_load(const char *extension_name, GType plugin_type);
 ValaPanelAppletInfo *vala_panel_applet_info_duplicate(void *info);
 void vala_panel_applet_info_free(void *info);
 
+GType vala_panel_applet_info_get_stored_type(ValaPanelAppletInfo *info);
 const char *vala_panel_applet_info_get_module_name(ValaPanelAppletInfo *info);
 const char *vala_panel_applet_info_get_name(ValaPanelAppletInfo *info);
 const char *vala_panel_applet_info_get_description(ValaPanelAppletInfo *info);
