@@ -25,9 +25,9 @@
 #include "panel-platform.h"
 #include "settings-manager.h"
 
-ValaPanelUnitSettings *vala_panel_unit_settings_new(ValaPanelCoreSettings *settings,
-                                                    const char *name, const char *uuid,
-                                                    bool is_toplevel)
+static ValaPanelUnitSettings *vp_unit_settings_new(ValaPanelCoreSettings *settings,
+                                                   const char *name, const char *uuid,
+                                                   bool is_toplevel)
 {
 	ValaPanelUnitSettings *created_settings = g_slice_new(ValaPanelUnitSettings);
 	created_settings->uuid                  = g_strdup(uuid);
@@ -53,22 +53,15 @@ ValaPanelUnitSettings *vala_panel_unit_settings_new(ValaPanelCoreSettings *setti
 	g_autoptr(GSettingsSchema) new_schema =
 	    g_settings_schema_source_lookup(source, tname, true);
 
-	/* Old way to find a schema */
-	g_autofree char *id = g_strdup_printf("%s.%s", settings->root_schema, tname);
-
-	g_autoptr(GSettingsSchema) old_schema = g_settings_schema_source_lookup(source, id, true);
 	if (new_schema != NULL)
 		created_settings->custom =
 		    g_settings_new_with_backend_and_path(tname, settings->backend, path);
-	else if (old_schema != NULL)
-		created_settings->custom =
-		    g_settings_new_with_backend_and_path(id, settings->backend, path);
 	else
 		created_settings->custom = NULL;
 	return created_settings;
 }
 
-static ValaPanelUnitSettings *vala_panel_unit_settings_copy(ValaPanelUnitSettings *source)
+static ValaPanelUnitSettings *vp_unit_settings_copy(ValaPanelUnitSettings *source)
 {
 	ValaPanelUnitSettings *created_settings = g_slice_new0(ValaPanelUnitSettings);
 	created_settings->uuid                  = g_strdup(source->uuid);
@@ -80,18 +73,19 @@ static ValaPanelUnitSettings *vala_panel_unit_settings_copy(ValaPanelUnitSetting
 	return created_settings;
 }
 
-void vala_panel_unit_settings_free(ValaPanelUnitSettings *settings)
+G_GNUC_INTERNAL void vp_unit_settings_free(ValaPanelUnitSettings *settings)
 {
 	if (!settings)
 		return;
 	g_clear_object(&settings->custom);
 	g_clear_object(&settings->common);
 	g_clear_object(&settings->type);
+	g_clear_pointer(&settings->uuid, g_free);
 	g_slice_free(ValaPanelUnitSettings, settings);
 }
 
-G_DEFINE_BOXED_TYPE(ValaPanelUnitSettings, vala_panel_unit_settings, vala_panel_unit_settings_copy,
-                    vala_panel_unit_settings_free)
+G_DEFINE_BOXED_TYPE(ValaPanelUnitSettings, vp_unit_settings, vp_unit_settings_copy,
+                    vp_unit_settings_free)
 
 bool vala_panel_unit_settings_is_toplevel(ValaPanelUnitSettings *settings)
 {
@@ -100,18 +94,17 @@ bool vala_panel_unit_settings_is_toplevel(ValaPanelUnitSettings *settings)
 	return !g_strcmp0(id, VALA_PANEL_TOPLEVEL_SCHEMA);
 }
 
-ValaPanelCoreSettings *vala_panel_core_settings_new(const char *schema, const char *path,
-                                                    GSettingsBackend *backend)
+G_GNUC_INTERNAL ValaPanelCoreSettings *vp_core_settings_new(const char *schema, const char *path,
+                                                            GSettingsBackend *backend)
 {
 	ValaPanelCoreSettings *new_settings = g_slice_new(ValaPanelCoreSettings);
-	new_settings->all_units =
-	    g_hash_table_new_full(g_str_hash,
-	                          g_str_equal,
-	                          g_free,
-	                          (GDestroyNotify)vala_panel_unit_settings_free);
-	new_settings->root_path   = g_strdup(path);
-	new_settings->root_schema = g_strdup(schema);
-	new_settings->backend     = g_object_ref(backend);
+	new_settings->all_units             = g_hash_table_new_full(g_str_hash,
+                                                        g_str_equal,
+                                                        g_free,
+                                                        (GDestroyNotify)vp_unit_settings_free);
+	new_settings->root_path             = g_strdup(path);
+	new_settings->root_schema           = g_strdup(schema);
+	new_settings->backend               = g_object_ref_sink(backend);
 	g_autofree char *core_path =
 	    g_strdup_printf("%s%s/", new_settings->root_path, VALA_PANEL_CORE_PATH_ELEM);
 	new_settings->core_settings = g_settings_new_with_backend_and_path(VALA_PANEL_CORE_SCHEMA,
@@ -120,7 +113,7 @@ ValaPanelCoreSettings *vala_panel_core_settings_new(const char *schema, const ch
 	return new_settings;
 }
 
-ValaPanelCoreSettings *vala_panel_core_settings_copy(ValaPanelCoreSettings *settings)
+G_GNUC_INTERNAL ValaPanelCoreSettings *vp_core_settings_copy(ValaPanelCoreSettings *settings)
 {
 	ValaPanelCoreSettings *new_settings = g_slice_new0(ValaPanelCoreSettings);
 	new_settings->root_path             = g_strdup(settings->root_path);
@@ -131,59 +124,60 @@ ValaPanelCoreSettings *vala_panel_core_settings_copy(ValaPanelCoreSettings *sett
 	return new_settings;
 }
 
-void vala_panel_core_settings_free(ValaPanelCoreSettings *settings)
+G_GNUC_INTERNAL void vp_core_settings_free(ValaPanelCoreSettings *settings)
 {
 	g_free0(settings->root_path);
 	g_free0(settings->root_schema);
 	g_clear_object(&settings->core_settings);
-	g_clear_object(&settings->backend);
 	g_hash_table_unref(settings->all_units);
+	g_clear_object(&settings->backend);
 	g_slice_free(ValaPanelCoreSettings, settings);
 }
 
-G_DEFINE_BOXED_TYPE(ValaPanelCoreSettings, vala_panel_core_settings, vala_panel_core_settings_copy,
-                    vala_panel_core_settings_free)
+G_DEFINE_BOXED_TYPE(ValaPanelCoreSettings, vp_core_settings, vp_core_settings_copy,
+                    vp_core_settings_free)
 
-static void vala_panel_core_settings_sync(ValaPanelCoreSettings *settings)
+static void vp_core_settings_sync(ValaPanelCoreSettings *settings)
 {
 	g_autofree GStrv unit_list =
-	    (GStrv)g_hash_table_get_keys_as_array(settings->all_units, NULL);
-	g_settings_set_strv(settings->core_settings, VALA_PANEL_CORE_UNITS, unit_list);
+	    (GStrv)g_hash_table_get_keys_as_array(settings->all_units, NULL); // We should free only
+	                                                                      // container here
+	g_settings_set_strv(settings->core_settings,
+	                    VALA_PANEL_CORE_UNITS,
+	                    (const char *const *)unit_list);
 }
 
-static ValaPanelUnitSettings *vala_panel_core_settings_load_unit_settings(
-    ValaPanelCoreSettings *settings, const char *uuid)
+static ValaPanelUnitSettings *vp_core_settings_load_unit_settings(ValaPanelCoreSettings *settings,
+                                                                  const char *uuid)
 {
 	g_autofree char *path = g_strdup_printf("%s%s/", settings->root_path, uuid);
 	g_autoptr(GSettings) s =
 	    g_settings_new_with_backend_and_path(VALA_PANEL_OBJECT_SCHEMA, settings->backend, path);
 	int en = g_settings_get_enum(s, VALA_PANEL_OBJECT_TYPE);
 	ValaPanelUnitSettings *usettings =
-	    vala_panel_unit_settings_new(settings, NULL, uuid, en == TOPLEVEL);
+	    vp_unit_settings_new(settings, NULL, uuid, en == TOPLEVEL);
 	g_hash_table_insert(settings->all_units, g_strdup(uuid), usettings);
 	return usettings;
 }
 
-ValaPanelUnitSettings *vala_panel_core_settings_add_unit_settings_full(
+G_GNUC_INTERNAL ValaPanelUnitSettings *vp_core_settings_add_unit_settings_full(
     ValaPanelCoreSettings *settings, const char *name, const char *uuid, bool is_toplevel)
 {
-	ValaPanelUnitSettings *usettings =
-	    vala_panel_unit_settings_new(settings, name, uuid, is_toplevel);
+	ValaPanelUnitSettings *usettings = vp_unit_settings_new(settings, name, uuid, is_toplevel);
 	g_hash_table_insert(settings->all_units, g_strdup(uuid), usettings);
-	vala_panel_core_settings_sync(settings);
+	vp_core_settings_sync(settings);
 	return usettings;
 }
 
-ValaPanelUnitSettings *vala_panel_core_settings_add_unit_settings(ValaPanelCoreSettings *settings,
-                                                                  const char *name,
-                                                                  bool is_toplevel)
+G_GNUC_INTERNAL ValaPanelUnitSettings *vp_core_settings_add_unit_settings(
+    ValaPanelCoreSettings *settings, const char *name, bool is_toplevel)
 {
-	g_autofree char *uuid = vala_panel_core_settings_get_uuid();
-	return vala_panel_core_settings_add_unit_settings_full(settings, name, uuid, is_toplevel);
+	g_autofree char *uuid = g_uuid_string_random();
+	return vp_core_settings_add_unit_settings_full(settings, name, uuid, is_toplevel);
 }
 
-void vala_panel_core_settings_remove_unit_settings_full(ValaPanelCoreSettings *settings,
-                                                        const char *name, bool destroy)
+G_GNUC_INTERNAL void vp_core_settings_remove_unit_settings_full(ValaPanelCoreSettings *settings,
+                                                                const char *name, bool destroy)
 {
 	if (destroy)
 	{
@@ -196,25 +190,23 @@ void vala_panel_core_settings_remove_unit_settings_full(ValaPanelCoreSettings *s
 	}
 	g_hash_table_remove(settings->all_units, name);
 	if (destroy)
-		vala_panel_core_settings_sync(settings);
+	{
+		vp_core_settings_sync(settings);
+		g_settings_sync();
+	}
 }
 
-ValaPanelUnitSettings *vala_panel_core_settings_get_by_uuid(ValaPanelCoreSettings *settings,
-                                                            const char *uuid)
+G_GNUC_INTERNAL ValaPanelUnitSettings *vp_core_settings_get_by_uuid(ValaPanelCoreSettings *settings,
+                                                                    const char *uuid)
 {
 	return (ValaPanelUnitSettings *)g_hash_table_lookup(settings->all_units, uuid);
 }
 
-bool vala_panel_core_settings_init_unit_list(ValaPanelCoreSettings *settings)
+G_GNUC_INTERNAL bool vp_core_settings_init_unit_list(ValaPanelCoreSettings *settings)
 {
 	g_auto(GStrv) unit_list =
 	    g_settings_get_strv(settings->core_settings, VALA_PANEL_CORE_UNITS);
 	for (int i = 0; unit_list[i] != NULL; i++)
-		vala_panel_core_settings_load_unit_settings(settings, unit_list[i]);
+		vp_core_settings_load_unit_settings(settings, unit_list[i]);
 	return g_hash_table_size(settings->all_units);
 }
-
-char *vala_panel_core_settings_get_uuid()
-{
-	return g_uuid_string_random();
-}
