@@ -18,7 +18,6 @@
 
 #include "toplevel-config.h"
 #include "applet-manager.h"
-#include "applet-plugin.h"
 #include "definitions.h"
 #include "panel-layout.h"
 #include "toplevel.h"
@@ -26,15 +25,40 @@
 
 #include "private.h"
 
-G_DEFINE_TYPE(ValaPanelToplevelConfig, vala_panel_toplevel_config, GTK_TYPE_DIALOG);
+struct _ValaPanelToplevelConfig
+{
+	GtkDialog parent_instance;
+	GtkStack *prefs_stack;
+	ValaPanelToplevel *_toplevel;
+	GtkComboBox *monitors_box;
+	GtkListStore *store_monitors;
+	GtkSpinButton *spin_iconsize;
+	GtkSpinButton *spin_height;
+	GtkSpinButton *spin_width;
+	GtkSpinButton *spin_corners;
+	GtkFontButton *font_selector;
+	GtkBox *font_box;
+	GtkColorButton *color_background;
+	GtkColorButton *color_foreground;
+	GtkFileChooserButton *file_background;
+	GtkListBox *plugin_list;
+	GtkStack *applet_info_stack;
+	GtkListBox *listbox_new_applet;
+	GtkButton *adding_button;
+	GtkButton *up_button;
+	GtkButton *down_button;
+	GtkButton *about_button;
+};
+
+G_DEFINE_TYPE(ValaPanelToplevelConfig, vp_toplevel_config, GTK_TYPE_DIALOG)
 
 static GQuark applet_quark;
 #define config_row_get_applet(row)                                                                 \
 	VALA_PANEL_APPLET(g_object_get_qdata((GObject *)row, applet_quark))
 #define config_row_set_applet(row, applet) g_object_set_qdata((GObject *)row, applet_quark, applet)
 
-#define config_row_get_info_data(row)                                                              \
-	((AppletInfoData *)(g_object_get_qdata((GObject *)row, applet_quark)))
+#define config_row_get_info(row)                                                                   \
+	((ValaPanelAppletInfo *)(g_object_get_qdata((GObject *)row, applet_quark)))
 #define config_row_set_info(row, applet) g_object_set_qdata((GObject *)row, applet_quark, applet)
 
 #define NEW_APPLET_NAME "new-applet"
@@ -51,15 +75,15 @@ enum
 	TOPLEVEL_PROPERTY,
 	NUM_PROPERTIES
 };
-static GParamSpec *vala_panel_toplevel_config_properties[NUM_PROPERTIES];
-static void state_configure_monitor(GSimpleAction *act, GVariant *param, void *data);
+static GParamSpec *vp_toplevel_config_properties[NUM_PROPERTIES];
 static void init_plugin_list(ValaPanelToplevelConfig *self);
 static void on_add_plugin_stack_box_generate(ValaPanelToplevelConfig *self);
 static void on_remove_plugin(GtkButton *btn, void *user_data);
 
-void vala_panel_toplevel_config_select_applet(ValaPanelToplevelConfig *self, const char *uuid)
+G_GNUC_INTERNAL void vp_toplevel_config_select_applet(ValaPanelToplevelConfig *self,
+                                                      const char *uuid)
 {
-	GList *ch               = gtk_container_get_children(self->plugin_list);
+	g_autoptr(GList) ch     = gtk_container_get_children(GTK_CONTAINER(self->plugin_list));
 	GtkListBoxRow *selected = NULL;
 	for (GList *l = ch; l != NULL; l = g_list_next(l))
 	{
@@ -68,18 +92,25 @@ void vala_panel_toplevel_config_select_applet(ValaPanelToplevelConfig *self, con
 			selected = GTK_LIST_BOX_ROW(l->data);
 	}
 	gtk_list_box_select_row(self->plugin_list, selected);
-	g_list_free(ch);
 }
 
-static void vala_panel_toplevel_config_init(ValaPanelToplevelConfig *self)
+G_GNUC_INTERNAL void vp_toplevel_config_select_page(ValaPanelToplevelConfig *self, const char *page)
+{
+	gtk_stack_set_visible_child_name(self->prefs_stack, page);
+}
+
+static void vp_toplevel_config_init(ValaPanelToplevelConfig *self)
 {
 	applet_quark = g_quark_from_static_string("vala-panel-applet-property");
 	gtk_widget_init_template(GTK_WIDGET(self));
 }
 
-static void vala_panel_configure_dialog_finalize(GObject *obj)
+static void vp_toplevel_config_finalize(GObject *obj)
 {
-	ValaPanelToplevelConfig *self = VALA_PANEL_TOPLEVEL_CONFIG(obj);
+	ValaPanelToplevelConfig *self = VP_TOPLEVEL_CONFIG(obj);
+	gtk_widget_insert_action_group(GTK_WIDGET(self), "conf", NULL);
+	gtk_widget_insert_action_group(GTK_WIDGET(self), "win", NULL);
+	gtk_widget_insert_action_group(GTK_WIDGET(self), "app", NULL);
 	g_clear_object(&self->monitors_box);
 	g_clear_object(&self->spin_iconsize);
 	g_clear_object(&self->spin_height);
@@ -97,38 +128,33 @@ static void vala_panel_configure_dialog_finalize(GObject *obj)
 	g_clear_object(&self->down_button);
 	g_clear_object(&self->about_button);
 	g_clear_object(&self->prefs_stack);
-	G_OBJECT_CLASS(vala_panel_toplevel_config_parent_class)->finalize(obj);
+	G_OBJECT_CLASS(vp_toplevel_config_parent_class)->finalize(obj);
 }
 
 static void on_monitors_changed(GtkComboBox *box, void *data)
 {
-	ValaPanelToplevelConfig *self = VALA_PANEL_TOPLEVEL_CONFIG(data);
-	int panel_gravity, monitor, request_mon;
-	g_object_get(self->_toplevel,
-	             VP_KEY_MONITOR,
-	             &monitor,
-	             VP_KEY_GRAVITY,
-	             &panel_gravity,
-	             NULL);
+	ValaPanelToplevelConfig *self = VP_TOPLEVEL_CONFIG(data);
+	ValaPanelToplevel *top        = self->_toplevel;
+	uint panel_gravity;
+	int request_mon;
+	g_object_get(top, VP_KEY_GRAVITY, &panel_gravity, NULL);
 
 	/* change monitor */
 	GtkTreeIter iter;
 	gtk_combo_box_get_active_iter(box, &iter);
 	gtk_tree_model_get(GTK_TREE_MODEL(self->store_monitors), &iter, 0, &request_mon, -1);
-	ValaPanelPlatform *pf = vala_panel_toplevel_get_current_platform();
-	if (vala_panel_platform_edge_available(pf,
-	                                       GTK_WINDOW(self->_toplevel),
+	if (vala_panel_platform_edge_available(vp_toplevel_get_current_platform(),
+	                                       GTK_WINDOW(top),
 	                                       panel_gravity,
 	                                       request_mon))
 	{
-		g_object_set(self->_toplevel, VP_KEY_MONITOR, request_mon, NULL);
-		gtk_combo_box_set_active(box, request_mon + 1);
+		g_object_set(top, VP_KEY_MONITOR, request_mon, NULL);
 	}
 }
 static void background_color_connector(GtkColorButton *colorb, void *data)
 {
 	GdkRGBA color;
-	gtk_color_chooser_get_rgba(colorb, &color);
+	gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(colorb), &color);
 	g_autofree char *chr_str = gdk_rgba_to_string(&color);
 	g_object_set(G_OBJECT(data), VP_KEY_BACKGROUND_COLOR, chr_str, NULL);
 }
@@ -136,7 +162,7 @@ static void background_color_connector(GtkColorButton *colorb, void *data)
 static void foreground_color_connector(GtkColorButton *colorb, void *data)
 {
 	GdkRGBA color;
-	gtk_color_chooser_get_rgba(colorb, &color);
+	gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(colorb), &color);
 	g_autofree char *chr_str = gdk_rgba_to_string(&color);
 	g_object_set(G_OBJECT(data), VP_KEY_FOREGROUND_COLOR, chr_str, NULL);
 }
@@ -145,17 +171,17 @@ static void background_file_connector(GtkFileChooser *colorb, void *data)
 	g_autofree char *chr_str = gtk_file_chooser_get_filename(colorb);
 	g_object_set(G_OBJECT(data), VP_KEY_BACKGROUND_FILE, chr_str, NULL);
 }
-static GObject *vala_panel_configure_dialog_constructor(GType type, guint n_construct_properties,
-                                                        GObjectConstructParam *construct_properties)
+static GObject *vp_toplevel_config_constructor(GType type, guint n_construct_properties,
+                                               GObjectConstructParam *construct_properties)
 {
-	GObjectClass *parent_class = G_OBJECT_CLASS(vala_panel_toplevel_config_parent_class);
+	GObjectClass *parent_class = G_OBJECT_CLASS(vp_toplevel_config_parent_class);
 	GObject *obj =
 	    parent_class->constructor(type, n_construct_properties, construct_properties);
-	ValaPanelToplevelConfig *self = VALA_PANEL_TOPLEVEL_CONFIG(obj);
-	GdkRGBA color;
+	ValaPanelToplevelConfig *self      = VP_TOPLEVEL_CONFIG(obj);
+	GdkRGBA color                      = { 0 };
 	g_autoptr(GSimpleActionGroup) conf = g_simple_action_group_new();
 	vala_panel_apply_window_icon(GTK_WINDOW(self));
-	gtk_window_set_transient_for(self, self->_toplevel);
+	gtk_window_set_transient_for(GTK_WINDOW(self), GTK_WINDOW(self->_toplevel));
 	/* monitors */
 	int monitors       = 0;
 	GdkDisplay *screen = gtk_widget_get_display(GTK_WIDGET(self->_toplevel));
@@ -165,21 +191,14 @@ static GObject *vala_panel_configure_dialog_constructor(GType type, guint n_cons
 	for (int i = 0; i < monitors; i++)
 	{
 		GtkTreeIter iter;
+		const char *model = gdk_monitor_get_model(gdk_display_get_monitor(screen, i));
 		gtk_list_store_append(self->store_monitors, &iter);
-		gtk_list_store_set(self->store_monitors,
-		                   &iter,
-		                   0,
-		                   i,
-		                   1,
-		                   gdk_monitor_get_model(gdk_display_get_monitor(screen, i)),
-		                   -1);
+		gtk_list_store_set(self->store_monitors, &iter, 0, i, 1, model, -1);
 	}
 	int true_monitor;
 	g_object_get(self->_toplevel, VP_KEY_MONITOR, &true_monitor, NULL);
 
 	gtk_combo_box_set_active(self->monitors_box, true_monitor + 1);
-	/* update monitor */
-	on_monitors_changed(self->monitors_box, self);
 
 	/* size */
 	g_object_bind_property(self->_toplevel,
@@ -222,7 +241,7 @@ static GObject *vala_panel_configure_dialog_constructor(GType type, guint n_cons
 	                       self->color_background,
 	                       "sensitive",
 	                       G_BINDING_SYNC_CREATE);
-	char *file = NULL;
+	g_autofree char *file = NULL;
 	bool use_background_file;
 	g_object_get(self->_toplevel,
 	             VP_KEY_BACKGROUND_FILE,
@@ -231,8 +250,8 @@ static GObject *vala_panel_configure_dialog_constructor(GType type, guint n_cons
 	             &use_background_file,
 	             NULL);
 	if (use_background_file && file != NULL)
-		gtk_file_chooser_set_filename(self->file_background, file);
-	gtk_widget_set_sensitive(self->file_background, use_background_file);
+		gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(self->file_background), file);
+	gtk_widget_set_sensitive(GTK_WIDGET(self->file_background), use_background_file);
 	g_object_bind_property(self->_toplevel,
 	                       VP_KEY_USE_BACKGROUND_FILE,
 	                       self->file_background,
@@ -242,8 +261,6 @@ static GObject *vala_panel_configure_dialog_constructor(GType type, guint n_cons
 	                 "file-set",
 	                 G_CALLBACK(background_file_connector),
 	                 self->_toplevel);
-	//    if(file)
-	//        g_free0(file);
 	/* foregorund */
 	g_object_get(self->_toplevel, VP_KEY_FOREGROUND_COLOR, &scol, NULL);
 	gdk_rgba_parse(&color, scol);
@@ -273,16 +290,18 @@ static GObject *vala_panel_configure_dialog_constructor(GType type, guint n_cons
 	/* plugin list */
 	init_plugin_list(self);
 	on_add_plugin_stack_box_generate(self);
-	gtk_widget_insert_action_group(self, "conf", conf);
-	gtk_widget_insert_action_group(self, "win", self->_toplevel);
-	gtk_widget_insert_action_group(self, "app", gtk_window_get_application(self->_toplevel));
+	GActionGroup *top_act =
+	    G_ACTION_GROUP(gtk_window_get_application(GTK_WINDOW(self->_toplevel)));
+	gtk_widget_insert_action_group(GTK_WIDGET(self), "conf", G_ACTION_GROUP(conf));
+	gtk_widget_insert_action_group(GTK_WIDGET(self), "win", G_ACTION_GROUP(self->_toplevel));
+	gtk_widget_insert_action_group(GTK_WIDGET(self), "app", top_act);
 	return obj;
 }
 
-static void vala_panel_toplevel_config_get_property(GObject *object, guint property_id,
-                                                    GValue *value, GParamSpec *pspec)
+static void vp_toplevel_config_get_property(GObject *object, guint property_id, GValue *value,
+                                            GParamSpec *pspec)
 {
-	ValaPanelToplevelConfig *self = VALA_PANEL_TOPLEVEL_CONFIG(object);
+	ValaPanelToplevelConfig *self = VP_TOPLEVEL_CONFIG(object);
 	switch (property_id)
 	{
 	case TOPLEVEL_PROPERTY:
@@ -294,10 +313,10 @@ static void vala_panel_toplevel_config_get_property(GObject *object, guint prope
 	}
 }
 
-static void vala_panel_toplevel_config_set_property(GObject *object, guint property_id,
-                                                    const GValue *value, GParamSpec *pspec)
+static void vp_toplevel_config_set_property(GObject *object, guint property_id, const GValue *value,
+                                            GParamSpec *pspec)
 {
-	ValaPanelToplevelConfig *self = VALA_PANEL_TOPLEVEL_CONFIG(object);
+	ValaPanelToplevelConfig *self = VP_TOPLEVEL_CONFIG(object);
 	switch (property_id)
 	{
 	case TOPLEVEL_PROPERTY:
@@ -311,59 +330,59 @@ static void vala_panel_toplevel_config_set_property(GObject *object, guint prope
 
 static ValaPanelAppletInfo *get_info_from_applet(ValaPanelApplet *pl)
 {
-	return vp_applet_manager_get_applet_info(vala_panel_layout_get_manager(),
+	return vp_applet_manager_get_applet_info(vp_layout_get_manager(),
 	                                         pl,
-	                                         vala_panel_toplevel_get_core_settings());
+	                                         vp_toplevel_get_core_settings());
 }
 
 static GtkListBoxRow *create_info_representation(ValaPanelAppletInfo *pl_info)
 {
-	GtkListBoxRow *row = gtk_list_box_row_new();
-	GtkBox *box        = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
+	GtkWidget *row = gtk_list_box_row_new();
+	GtkWidget *box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
 	gtk_widget_show(box);
-	gtk_container_add(row, box);
+	gtk_container_add(GTK_CONTAINER(row), box);
 
 	gtk_widget_set_margin_top(box, 4);
 	gtk_widget_set_margin_bottom(box, 4);
 
-	GtkImage *image =
-	    GTK_IMAGE(gtk_image_new_from_icon_name(vala_panel_applet_info_get_icon_name(pl_info),
-	                                           GTK_ICON_SIZE_BUTTON));
+	GtkWidget *image =
+	    gtk_image_new_from_icon_name(vala_panel_applet_info_get_icon_name(pl_info),
+	                                 GTK_ICON_SIZE_BUTTON);
 	gtk_widget_set_margin_start(image, 12);
 	gtk_widget_set_margin_end(image, 14);
 	gtk_widget_show(image);
-	gtk_box_pack_start(box, image, false, false, 0);
+	gtk_box_pack_start(GTK_BOX(box), image, false, false, 0);
 
-	GtkLabel *label = gtk_label_new(vala_panel_applet_info_get_name(pl_info));
+	GtkWidget *label = gtk_label_new(vala_panel_applet_info_get_name(pl_info));
 	gtk_widget_set_margin_end(label, 18);
 	gtk_widget_set_halign(label, GTK_ALIGN_START);
 	gtk_widget_show(label);
-	gtk_box_pack_start(box, label, false, false, 0);
+	gtk_box_pack_start(GTK_BOX(box), label, false, false, 0);
 	gtk_widget_show(box);
 	gtk_widget_show(row);
-	return row;
+	return GTK_LIST_BOX_ROW(row);
 }
 
 static GtkListBoxRow *create_applet_representation(ValaPanelToplevelConfig *self,
                                                    ValaPanelApplet *pl)
 {
 	ValaPanelAppletInfo *pl_info =
-	    vp_applet_manager_get_applet_info(vala_panel_layout_get_manager(),
+	    vp_applet_manager_get_applet_info(vp_layout_get_manager(),
 	                                      pl,
-	                                      vala_panel_toplevel_get_core_settings());
+	                                      vp_toplevel_get_core_settings());
 	GtkListBoxRow *row = create_info_representation(pl_info);
-	GtkBox *box        = GTK_BOX(gtk_bin_get_child(row));
-	GtkButton *button  = GTK_BUTTON(gtk_button_new());
-	GtkImage *image = gtk_image_new_from_icon_name("list-remove-symbolic", GTK_ICON_SIZE_MENU);
+	GtkBox *box        = GTK_BOX(gtk_bin_get_child(GTK_BIN(row)));
+	GtkWidget *button  = gtk_button_new();
+	GtkWidget *image = gtk_image_new_from_icon_name("list-remove-symbolic", GTK_ICON_SIZE_MENU);
 	gtk_widget_show(image);
-	gtk_container_add(button, image);
+	gtk_container_add(GTK_CONTAINER(button), image);
 	gtk_widget_show(button);
 	GtkStyleContext *context = gtk_widget_get_style_context(GTK_WIDGET(button));
 	gtk_style_context_add_class(context, "circular");
 	gtk_style_context_add_class(context, "destructive-action");
-	gtk_button_set_relief(button, GTK_RELIEF_NONE);
+	gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
 	gtk_box_pack_end(box, button, false, false, 0);
-	g_signal_connect(button, "clicked", on_remove_plugin, self);
+	g_signal_connect(button, "clicked", G_CALLBACK(on_remove_plugin), self);
 	config_row_set_applet(row, pl);
 	return row;
 }
@@ -376,15 +395,15 @@ static int plugin_list_sort(GtkListBoxRow *before, GtkListBoxRow *after, void *u
 	ValaPanelLayout *layout      = VALA_PANEL_LAYOUT(user_data);
 	ValaPanelApplet *before_info = before ? config_row_get_applet(before) : NULL;
 	ValaPanelApplet *after_info  = after ? config_row_get_applet(after) : NULL;
-	uint bpos                    = vala_panel_layout_get_applet_position(layout, before_info);
-	uint apos                    = vala_panel_layout_get_applet_position(layout, after_info);
-	int bi                       = vala_panel_layout_get_applet_pack_type(before_info);
+	uint bpos                    = vp_layout_get_applet_position(layout, before_info);
+	uint apos                    = vp_layout_get_applet_position(layout, after_info);
+	uint bi                      = vp_layout_get_applet_pack_type(before_info);
 
 	if (before_info != NULL && after_info != NULL &&
-	    vala_panel_layout_get_applet_pack_type(before_info) !=
-	        vala_panel_layout_get_applet_pack_type(after_info))
+	    vp_layout_get_applet_pack_type(before_info) !=
+	        vp_layout_get_applet_pack_type(after_info))
 	{
-		int ai = vala_panel_layout_get_applet_pack_type(after_info);
+		uint ai = vp_layout_get_applet_pack_type(after_info);
 		if (ai != bi)
 		{
 			if (bi == PACK_START || ai == PACK_END)
@@ -409,12 +428,13 @@ static int plugin_list_sort(GtkListBoxRow *before, GtkListBoxRow *after, void *u
 /**
  * Provide headers in the list to separate the visual positions
  */
-static void plugin_list_headers(GtkListBoxRow *before, GtkListBoxRow *after, void *user_data)
+static void plugin_list_headers(GtkListBoxRow *before, GtkListBoxRow *after,
+                                G_GNUC_UNUSED void *user_data)
 {
 	ValaPanelApplet *before_info = before ? config_row_get_applet(before) : NULL;
 	ValaPanelApplet *after_info  = after ? config_row_get_applet(after) : NULL;
-	int prev        = before_info ? vala_panel_layout_get_applet_pack_type(before_info) : -1;
-	int next        = after_info ? vala_panel_layout_get_applet_pack_type(after_info) : -1;
+	int prev        = before_info ? (int)vp_layout_get_applet_pack_type(before_info) : -1;
+	int next        = after_info ? (int)vp_layout_get_applet_pack_type(after_info) : -1;
 	GtkLabel *label = GTK_LABEL(gtk_list_box_row_get_header(before));
 
 	if (after == NULL || prev != next)
@@ -448,21 +468,22 @@ static void plugin_list_headers(GtkListBoxRow *before, GtkListBoxRow *after, voi
 		gtk_list_box_row_set_header(before, NULL);
 }
 
-static void on_plugin_list_row_selected(GtkListBox *box, GtkListBoxRow *row, gpointer data)
+static void on_plugin_list_row_selected(G_GNUC_UNUSED GtkListBox *box, GtkListBoxRow *row,
+                                        gpointer data)
 {
-	ValaPanelToplevelConfig *self = VALA_PANEL_TOPLEVEL_CONFIG(data);
+	ValaPanelToplevelConfig *self = VP_TOPLEVEL_CONFIG(data);
 	if (!row)
 	{
-		gtk_widget_set_sensitive(self->about_button, false);
-		gtk_widget_set_sensitive(self->up_button, false);
-		gtk_widget_set_sensitive(self->down_button, false);
+		gtk_widget_set_sensitive(GTK_WIDGET(self->about_button), false);
+		gtk_widget_set_sensitive(GTK_WIDGET(self->up_button), false);
+		gtk_widget_set_sensitive(GTK_WIDGET(self->down_button), false);
 		gtk_stack_set_visible_child_name(self->applet_info_stack, NO_SETTINGS);
 	}
 	else
 	{
 		ValaPanelApplet *pl     = config_row_get_applet(row);
 		ValaPanelLayout *layout = vala_panel_toplevel_get_layout(self->_toplevel);
-		gtk_widget_set_sensitive(self->about_button, true);
+		gtk_widget_set_sensitive(GTK_WIDGET(self->about_button), true);
 		GtkListBoxRow *down_row =
 		    gtk_list_box_get_row_at_index(self->plugin_list,
 		                                  gtk_list_box_row_get_index(row) + 1);
@@ -471,16 +492,10 @@ static void on_plugin_list_row_selected(GtkListBox *box, GtkListBoxRow *row, gpo
 		    gtk_list_box_get_row_at_index(self->plugin_list,
 		                                  gtk_list_box_row_get_index(row) - 1);
 		ValaPanelApplet *up = up_row ? config_row_get_applet(up_row) : NULL;
-		gtk_widget_set_sensitive(self->up_button,
-		                         vala_panel_layout_can_move_to_direction(layout,
-		                                                                 pl,
-		                                                                 up,
-		                                                                 GTK_PACK_START));
-		gtk_widget_set_sensitive(self->down_button,
-		                         vala_panel_layout_can_move_to_direction(layout,
-		                                                                 pl,
-		                                                                 down,
-		                                                                 GTK_PACK_END));
+		bool c_m_up   = vp_layout_can_move_to_direction(layout, pl, up, GTK_PACK_START);
+		bool c_m_down = vp_layout_can_move_to_direction(layout, pl, down, GTK_PACK_END);
+		gtk_widget_set_sensitive(GTK_WIDGET(self->up_button), c_m_up);
+		gtk_widget_set_sensitive(GTK_WIDGET(self->down_button), c_m_down);
 		if (vala_panel_applet_is_configurable(pl))
 			gtk_stack_set_visible_child_name(self->applet_info_stack,
 			                                 vala_panel_applet_get_uuid(pl));
@@ -502,11 +517,11 @@ static void plugin_list_add_applet(const char *type, ValaPanelToplevelConfig *se
 	ValaPanelLayout *layout  = vala_panel_toplevel_get_layout(self->_toplevel);
 	ValaPanelApplet *prev_pl = prev ? config_row_get_applet(prev) : NULL;
 	ValaPanelAppletPackType prev_pack =
-	    prev ? vala_panel_layout_get_applet_pack_type(prev_pl) : PACK_START;
-	uint prev_pos       = prev ? vala_panel_layout_get_applet_position(layout, prev_pl) : 0;
-	ValaPanelApplet *pl = vala_panel_layout_insert_applet(layout, type, prev_pack, prev_pos);
+	    prev ? vp_layout_get_applet_pack_type(prev_pl) : PACK_START;
+	uint prev_pos       = prev ? vp_layout_get_applet_position(layout, prev_pl) : 0;
+	ValaPanelApplet *pl = vp_layout_insert_applet(layout, type, prev_pack, prev_pos);
 	GtkListBoxRow *row  = create_applet_representation(self, pl);
-	gtk_container_add(self->plugin_list, row);
+	gtk_container_add(GTK_CONTAINER(self->plugin_list), GTK_WIDGET(row));
 	plugin_list_generate_applet_settings(pl, self);
 	gtk_list_box_invalidate_sort(self->plugin_list);
 }
@@ -515,7 +530,6 @@ static void init_plugin_list(ValaPanelToplevelConfig *self)
 {
 	GList *plugins =
 	    vala_panel_layout_get_applets_list(vala_panel_toplevel_get_layout(self->_toplevel));
-	GtkListBoxRow *prev;
 	for (GList *l = plugins; l != NULL; l = g_list_next(l))
 	{
 		ValaPanelApplet *w = VALA_PANEL_APPLET(l->data);
@@ -523,6 +537,7 @@ static void init_plugin_list(ValaPanelToplevelConfig *self)
 		gtk_container_add(GTK_CONTAINER(self->plugin_list), GTK_WIDGET(r));
 		plugin_list_generate_applet_settings(w, self);
 	}
+	g_clear_pointer(&plugins, g_list_free);
 	gtk_list_box_set_sort_func(self->plugin_list,
 	                           plugin_list_sort,
 	                           vala_panel_toplevel_get_layout(self->_toplevel),
@@ -531,9 +546,9 @@ static void init_plugin_list(ValaPanelToplevelConfig *self)
 	on_plugin_list_row_selected(self->plugin_list, NULL, self);
 }
 
-static void on_about_plugin(GtkButton *btn, void *data)
+static void on_about_plugin(G_GNUC_UNUSED GtkButton *btn, void *data)
 {
-	ValaPanelToplevelConfig *self = VALA_PANEL_TOPLEVEL_CONFIG(data);
+	ValaPanelToplevelConfig *self = VP_TOPLEVEL_CONFIG(data);
 	GtkListBoxRow *row            = gtk_list_box_get_selected_row(self->plugin_list);
 	if (!row)
 		return;
@@ -542,37 +557,35 @@ static void on_about_plugin(GtkButton *btn, void *data)
 	vala_panel_applet_info_show_about_dialog(info);
 }
 
-static int listbox_new_name_sort(GtkListBoxRow *before, GtkListBoxRow *after, void *user_data)
+static int listbox_new_name_sort(GtkListBoxRow *before, GtkListBoxRow *after,
+                                 G_GNUC_UNUSED void *user_data)
 {
-	AppletInfoData *before_info = before ? config_row_get_info_data(before) : NULL;
-	AppletInfoData *after_info  = after ? config_row_get_info_data(after) : NULL;
+	ValaPanelAppletInfo *before_info = before ? config_row_get_info(before) : NULL;
+	ValaPanelAppletInfo *after_info  = after ? config_row_get_info(after) : NULL;
 	if (before_info && after_info)
-		return g_strcmp0(vala_panel_applet_info_get_name(before_info->info),
-		                 vala_panel_applet_info_get_name(after_info->info));
+		return g_strcmp0(vala_panel_applet_info_get_name(before_info),
+		                 vala_panel_applet_info_get_name(after_info));
 	else if (before_info)
 		return -1;
 	else
 		return 1;
 }
 
-static void listbox_new_applet_row_activated(GtkListBox *box, GtkListBoxRow *row,
+static void listbox_new_applet_row_activated(G_GNUC_UNUSED GtkListBox *box, GtkListBoxRow *row,
                                              gpointer user_data)
 {
-	ValaPanelToplevelConfig *self = VALA_PANEL_TOPLEVEL_CONFIG(user_data);
-	const char *type =
-	    vala_panel_applet_info_get_module_name(config_row_get_info_data(row)->info);
+	ValaPanelToplevelConfig *self = VP_TOPLEVEL_CONFIG(user_data);
+	const char *type    = vala_panel_applet_info_get_module_name(config_row_get_info(row));
 	GtkListBoxRow *prev = gtk_list_box_get_selected_row(self->plugin_list);
 	plugin_list_add_applet(type, self, prev);
 	gtk_list_box_invalidate_filter(self->listbox_new_applet);
 }
 
-static int listbox_new_filter(GtkListBoxRow *row, void *data)
+static int listbox_new_filter(GtkListBoxRow *row, G_GNUC_UNUSED void *data)
 {
-	AppletInfoData *d = config_row_get_info_data(row);
-	bool ret          = false;
-	if ((d->count < 1) || !vala_panel_applet_info_is_exclusive(d->info))
-		ret = true;
-	return ret;
+	ValaPanelAppletInfo *d = config_row_get_info(row);
+	return vp_applet_manager_is_applet_available(vp_layout_get_manager(),
+	                                             vala_panel_applet_info_get_module_name(d));
 }
 
 static void destroy(GtkWidget *applet, G_GNUC_UNUSED void *data)
@@ -584,15 +597,15 @@ static void available_plugins_reload(ValaPanelToplevelConfig *self)
 {
 	/* Populate list of available plugins.
 	 * Omit plugins that can only exist once per system if it is already configured. */
-	vp_applet_manager_reload_applets(vala_panel_layout_get_manager());
+	vp_applet_manager_reload_applets(vp_layout_get_manager());
 	gtk_container_foreach(GTK_CONTAINER(self->listbox_new_applet), (GtkCallback)destroy, NULL);
-	GList *all_types = vp_applet_manager_get_all_types(vala_panel_layout_get_manager());
+	GList *all_types = vp_applet_manager_get_all_types(vp_layout_get_manager());
 	for (GList *l = all_types; l != NULL; l = g_list_next(l))
 	{
 		AppletInfoData *d  = (AppletInfoData *)l->data;
 		GtkListBoxRow *row = create_info_representation(d->info);
-		config_row_set_info(row, d);
-		gtk_container_add(self->listbox_new_applet, row);
+		config_row_set_info(row, d->info);
+		gtk_container_add(GTK_CONTAINER(self->listbox_new_applet), GTK_WIDGET(row));
 	}
 	g_list_free(all_types);
 }
@@ -607,7 +620,7 @@ static void on_add_plugin_stack_box_generate(ValaPanelToplevelConfig *self)
 	                             NULL);
 }
 
-static void on_add_plugin(GtkButton *btn, ValaPanelToplevelConfig *self)
+static void on_add_plugin(G_GNUC_UNUSED GtkButton *btn, ValaPanelToplevelConfig *self)
 {
 	const char *name = gtk_stack_get_visible_child_name(self->applet_info_stack);
 	if (!g_strcmp0(name, NEW_APPLET_NAME))
@@ -617,45 +630,43 @@ static void on_add_plugin(GtkButton *btn, ValaPanelToplevelConfig *self)
 		return;
 	}
 	available_plugins_reload(self);
-	gtk_widget_set_sensitive(self->about_button, false);
-	gtk_widget_set_sensitive(self->up_button, false);
-	gtk_widget_set_sensitive(self->down_button, false);
+	gtk_widget_set_sensitive(GTK_WIDGET(self->about_button), false);
+	gtk_widget_set_sensitive(GTK_WIDGET(self->up_button), false);
+	gtk_widget_set_sensitive(GTK_WIDGET(self->down_button), false);
 	gtk_stack_set_visible_child_name(self->applet_info_stack, NEW_APPLET_NAME);
 }
 
-static inline GtkListBoxRow *get_row_from_btn(GtkButton *self)
+static inline GtkWidget *get_row_from_btn(GtkButton *self)
 {
-	return GTK_LIST_BOX_ROW(gtk_widget_get_ancestor(GTK_WIDGET(self), GTK_TYPE_LIST_BOX_ROW));
+	return gtk_widget_get_ancestor(GTK_WIDGET(self), GTK_TYPE_LIST_BOX_ROW);
 }
 
 static void on_remove_plugin(GtkButton *btn, void *user_data)
 {
-	ValaPanelToplevelConfig *self = VALA_PANEL_TOPLEVEL_CONFIG(user_data);
-	GtkListBoxRow *row            = get_row_from_btn(btn);
+	ValaPanelToplevelConfig *self = VP_TOPLEVEL_CONFIG(user_data);
+	GtkWidget *row                = get_row_from_btn(btn);
 	if (!row)
 		return;
 	ValaPanelApplet *pl = config_row_get_applet(row);
 	GtkWidget *w =
 	    gtk_stack_get_child_by_name(self->applet_info_stack, vala_panel_applet_get_uuid(pl));
-	int index              = gtk_list_box_row_get_index(row);
+	int index              = gtk_list_box_row_get_index(GTK_LIST_BOX_ROW(row));
 	GtkListBoxRow *sel_row = gtk_list_box_get_selected_row(self->plugin_list);
 	int sel_index          = sel_row ? gtk_list_box_row_get_index(sel_row) : -1;
-	gtk_widget_destroy0(row);
-	gtk_widget_destroy0(w);
+	g_clear_object(&row);
+	g_clear_object(&w);
 	if (index == sel_index)
 		gtk_list_box_select_row(self->plugin_list,
 		                        gtk_list_box_get_row_at_index(self->plugin_list, index));
-	ValaPanelLayout *layout      = vala_panel_toplevel_get_layout(self->_toplevel);
-	ValaPanelAppletPackType pack = vala_panel_layout_get_applet_pack_type(pl);
-	uint pos                     = vala_panel_layout_get_applet_position(layout, pl);
-	vala_panel_layout_remove_applet(layout, pl);
+	ValaPanelLayout *layout = vala_panel_toplevel_get_layout(self->_toplevel);
+	vp_layout_remove_applet(layout, pl);
 	gtk_list_box_invalidate_sort(self->plugin_list);
 	gtk_list_box_invalidate_filter(self->listbox_new_applet);
 }
 
-static void on_moveup_plugin(GtkButton *btn, void *user_data)
+static void on_moveup_plugin(G_GNUC_UNUSED GtkButton *btn, void *user_data)
 {
-	ValaPanelToplevelConfig *self = VALA_PANEL_TOPLEVEL_CONFIG(user_data);
+	ValaPanelToplevelConfig *self = VP_TOPLEVEL_CONFIG(user_data);
 	ValaPanelLayout *layout       = vala_panel_toplevel_get_layout(self->_toplevel);
 	GtkListBoxRow *row            = gtk_list_box_get_selected_row(self->plugin_list);
 	if (!row)
@@ -665,14 +676,14 @@ static void on_moveup_plugin(GtkButton *btn, void *user_data)
 	index--;
 	GtkListBoxRow *nxt      = gtk_list_box_get_row_at_index(self->plugin_list, index);
 	ValaPanelApplet *nxt_pl = nxt ? config_row_get_applet(nxt) : NULL;
-	vala_panel_layout_move_applet_one_step(layout, pl, nxt_pl, GTK_PACK_START);
+	vp_layout_move_applet_one_step(layout, pl, nxt_pl, GTK_PACK_START);
 	gtk_list_box_invalidate_headers(self->plugin_list);
 	gtk_list_box_invalidate_sort(self->plugin_list);
 }
 
-static void on_movedown_plugin(GtkButton *btn, void *user_data)
+static void on_movedown_plugin(G_GNUC_UNUSED GtkButton *btn, void *user_data)
 {
-	ValaPanelToplevelConfig *self = VALA_PANEL_TOPLEVEL_CONFIG(user_data);
+	ValaPanelToplevelConfig *self = VP_TOPLEVEL_CONFIG(user_data);
 	ValaPanelLayout *layout       = vala_panel_toplevel_get_layout(self->_toplevel);
 	GtkListBoxRow *row            = gtk_list_box_get_selected_row(self->plugin_list);
 	if (!row)
@@ -682,28 +693,27 @@ static void on_movedown_plugin(GtkButton *btn, void *user_data)
 	index++;
 	GtkListBoxRow *nxt      = gtk_list_box_get_row_at_index(self->plugin_list, index);
 	ValaPanelApplet *nxt_pl = nxt ? config_row_get_applet(nxt) : NULL;
-	vala_panel_layout_move_applet_one_step(layout, pl, nxt_pl, GTK_PACK_END);
+	vp_layout_move_applet_one_step(layout, pl, nxt_pl, GTK_PACK_END);
 	gtk_list_box_invalidate_headers(self->plugin_list);
 	gtk_list_box_invalidate_sort(self->plugin_list);
 }
 
-static void vala_panel_toplevel_config_class_init(ValaPanelToplevelConfigClass *klass)
+static void vp_toplevel_config_class_init(ValaPanelToplevelConfigClass *klass)
 {
-	vala_panel_toplevel_config_parent_class = g_type_class_peek_parent(klass);
-	G_OBJECT_CLASS(klass)->get_property     = vala_panel_toplevel_config_get_property;
-	G_OBJECT_CLASS(klass)->set_property     = vala_panel_toplevel_config_set_property;
-	G_OBJECT_CLASS(klass)->constructor      = vala_panel_configure_dialog_constructor;
-	G_OBJECT_CLASS(klass)->finalize         = vala_panel_configure_dialog_finalize;
-	vala_panel_toplevel_config_properties[TOPLEVEL_PROPERTY] =
+	G_OBJECT_CLASS(klass)->get_property = vp_toplevel_config_get_property;
+	G_OBJECT_CLASS(klass)->set_property = vp_toplevel_config_set_property;
+	G_OBJECT_CLASS(klass)->constructor  = vp_toplevel_config_constructor;
+	G_OBJECT_CLASS(klass)->finalize     = vp_toplevel_config_finalize;
+	vp_toplevel_config_properties[TOPLEVEL_PROPERTY] =
 	    g_param_spec_object(VP_KEY_TOPLEVEL,
 	                        VP_KEY_TOPLEVEL,
 	                        VP_KEY_TOPLEVEL,
 	                        VALA_PANEL_TYPE_TOPLEVEL,
-	                        (GParamFlags)(G_PARAM_STATIC_STRINGS | G_PARAM_READABLE |
-	                                      G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property(G_OBJECT_CLASS(klass),
-	                                TOPLEVEL_PROPERTY,
-	                                vala_panel_toplevel_config_properties[TOPLEVEL_PROPERTY]);
+	                        (GParamFlags)(G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE |
+	                                      G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_properties(G_OBJECT_CLASS(klass),
+	                                  NUM_PROPERTIES,
+	                                  vp_toplevel_config_properties);
 	gtk_widget_class_set_template_from_resource(GTK_WIDGET_CLASS(klass),
 	                                            "/org/vala-panel/lib/pref.ui");
 	gtk_widget_class_bind_template_child_full(GTK_WIDGET_CLASS(klass),
